@@ -2,15 +2,15 @@
 
 import numpy as np
 import os
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
 from plantcv.plantcv import fatal_error
 from plantcv.plantcv import params
+from plantcv.plantcv._debug import _debug
 from skimage.morphology import remove_small_objects
 
 
 def fill(bin_img, size):
-    """Identifies objects and fills objects that are less than size.
+    """
+    Identifies objects and fills objects that are less than size.
 
     Inputs:
     bin_img      = Binary image data
@@ -24,8 +24,6 @@ def fill(bin_img, size):
     :param size: int
     :return filtered_img: numpy.ndarray
     """
-    params.device += 1
-
     # Make sure the image is binary
     if len(np.shape(bin_img)) != 2 or len(np.unique(bin_img)) != 2:
         fatal_error("Image is not binary")
@@ -39,9 +37,7 @@ def fill(bin_img, size):
     # Cast boolean image to binary and make a copy of the binary image for returning
     filtered_img = np.copy(bool_img.astype(np.uint8) * 255)
 
-    if params.debug == 'print':
-        print_image(filtered_img, os.path.join(params.debug_outdir, str(params.device) + '_fill' + str(size) + '.png'))
-    elif params.debug == 'plot':
-        plot_image(filtered_img, cmap='gray')
+    _debug(visual=filtered_img,
+           filename=os.path.join(params.debug_outdir, str(params.device) + "_fill" + str(size) + '.png'))
 
     return filtered_img
