@@ -1,18 +1,16 @@
 # Analyze reflectance signal data in an index
 
 import os
-import cv2
 import numpy as np
-import pandas as pd
-from plantcv.plantcv import params
+from plantcv.plantcv import deprecation_warning, params
 from plantcv.plantcv import outputs
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import fatal_error
-from plotnine import ggplot, aes, geom_line, scale_x_continuous
+from plantcv.plantcv.visualize import histogram
+from plotnine import labs
 
 
-def analyze_index(index_array, mask, histplot=False, bins=100, min_bin=0, max_bin=1):
+def analyze_index(index_array, mask, bins=100, min_bin=0, max_bin=1, histplot=None, label="default"):
     """This extracts the hyperspectral index statistics and writes the values  as observations out to
        the Outputs class.
 
@@ -23,6 +21,8 @@ def analyze_index(index_array, mask, histplot=False, bins=100, min_bin=0, max_bi
     bins         = optional, number of classes to divide spectrum into
     min_bin      = optional, minimum bin value ("auto" or user input minimum value)
     max_bin      = optional, maximum bin value ("auto" or user input maximum value)
+    label        = optional label parameter, modifies the variable name of observations recorded
+
 
 
     :param index_array: __main__.Spectral_data
@@ -31,13 +31,15 @@ def analyze_index(index_array, mask, histplot=False, bins=100, min_bin=0, max_bi
     :param bins: int
     :param max_bin: float, str
     :param min_bin: float, str
+    :param label: str
     :return analysis_image: ggplot, None
     """
-    params.device += 1
+    if histplot is not None:
+        deprecation_warning("'histplot' will be deprecated in a future version of PlantCV. "
+                            "This function creates a histogram by default.")
 
     debug = params.debug
     params.debug = None
-    analysis_image = None
 
     if len(np.shape(mask)) > 2 or len(np.unique(mask)) > 2:
         fatal_error("Mask should be a binary image of 0 and nonzero values.")
@@ -47,9 +49,11 @@ def analyze_index(index_array, mask, histplot=False, bins=100, min_bin=0, max_bi
 
     # Mask data and collect statistics about pixels within the masked image
     masked_array = index_array.array_data[np.where(mask > 0)]
-    index_mean = np.average(masked_array)
-    index_median = np.median(masked_array)
-    index_std = np.std(masked_array)
+    masked_array = masked_array[np.isfinite(masked_array)]
+
+    index_mean = np.nanmean(masked_array)
+    index_median = np.nanmedian(masked_array)
+    index_std = np.nanstd(masked_array)
 
     # Set starting point and max bin values
     maxval = max_bin
@@ -72,60 +76,42 @@ def analyze_index(index_array, mask, histplot=False, bins=100, min_bin=0, max_bi
               ", " + str(maxval) + "]. Adjust min_bin and max_bin in order to avoid cutting off data being collected.")
 
     # Calculate histogram
-    hist_val = [float(i[0]) for i in cv2.calcHist([masked_array.astype(np.float32)], [0], None, [bins], [b, maxval])]
-    bin_width = (maxval - b) / float(bins)
-    bin_labels = [float(b)]
-    plotting_labels = [float(b)]
-    for i in range(bins - 1):
-        b += bin_width
-        bin_labels.append(b)
-        plotting_labels.append(round(b, 2))
-
-    # Make hist percentage for plotting
-    pixels = cv2.countNonZero(mask)
-    hist_percent = [(p / float(pixels)) * 100 for p in hist_val]
+    hist_fig, hist_data = histogram(index_array.array_data, mask=mask, bins=bins, lower_bound=b, upper_bound=maxval,
+                                    hist_data=True)
+    bin_labels, hist_percent = hist_data['pixel intensity'].tolist(), hist_data['proportion of pixels (%)'].tolist()
 
+    # Restore user debug setting
     params.debug = debug
+    hist_fig = hist_fig + labs(x='Index Reflectance', y='Proportion of pixels (%)')
 
-    if histplot is True:
-        dataset = pd.DataFrame({'Index Reflectance': bin_labels,
-                                'Proportion of pixels (%)': hist_percent})
-        fig_hist = (ggplot(data=dataset,
-                           mapping=aes(x='Index Reflectance',
-                                       y='Proportion of pixels (%)'))
-                    + geom_line(color='red')
-                    + scale_x_continuous(breaks=bin_labels, labels=plotting_labels))
-        analysis_image = fig_hist
-        if params.debug == 'print':
-            fig_hist.save(os.path.join(params.debug_outdir,
-                                       str(params.device) + index_array.array_type + "hist.png"))
-        elif params.debug == 'plot':
-            print(fig_hist)
+    # Print or plot histogram
+    _debug(visual=hist_fig,
+           filename=os.path.join(params.debug_outdir, str(params.device) + index_array.array_type + "_hist.png"))
 
-    outputs.add_observation(variable='mean_' + index_array.array_type,
+    analysis_image = hist_fig
+
+    outputs.add_observation(sample=label, variable='mean_' + index_array.array_type,
                             trait='Average ' + index_array.array_type + ' reflectance',
                             method='plantcv.plantcv.hyperspectral.analyze_index', scale='reflectance', datatype=float,
                             value=float(index_mean), label='none')
 
-    outputs.add_observation(variable='med_' + index_array.array_type,
+    outputs.add_observation(sample=label, variable='med_' + index_array.array_type,
                             trait='Median ' + index_array.array_type + ' reflectance',
                             method='plantcv.plantcv.hyperspectral.analyze_index', scale='reflectance', datatype=float,
                             value=float(index_median), label='none')
 
-    outputs.add_observation(variable='std_' + index_array.array_type,
+    outputs.add_observation(sample=label, variable='std_' + index_array.array_type,
                             trait='Standard deviation ' + index_array.array_type + ' reflectance',
                             method='plantcv.plantcv.hyperspectral.analyze_index', scale='reflectance', datatype=float,
                             value=float(index_std), label='none')
 
-    outputs.add_observation(variable='index_frequencies_' + index_array.array_type, trait='index frequencies',
-                            method='plantcv.plantcv.analyze_index', scale='frequency', datatype=list,
-                            value=hist_percent, label=bin_labels)
+    outputs.add_observation(sample=label, variable='index_frequencies_' + index_array.array_type,
+                            trait='index frequencies', method='plantcv.plantcv.analyze_index', scale='frequency',
+                            datatype=list, value=hist_percent, label=bin_labels)
 
-    if params.debug == "plot":
-        plot_image(masked_array)
-    elif params.debug == "print":
-        print_image(img=masked_array, filename=os.path.join(params.debug_outdir, str(params.device) +
-                                                            index_array.array_type + ".png"))
+    # Print or plot the masked image
+    _debug(visual=masked_array,
+           filename=os.path.join(params.debug_outdir, str(params.device) + index_array.array_type + ".png"))
     # Store images
     outputs.images.append(analysis_image)
 
