@@ -3,12 +3,13 @@
 import os
 import numpy as np
 import pandas as pd
-from plantcv.plantcv import params
+from plantcv.plantcv import deprecation_warning, params
 from plantcv.plantcv import outputs
+from plantcv.plantcv._debug import _debug
 from plotnine import ggplot, aes, geom_line, scale_x_continuous
 
 
-def analyze_spectral(array, mask, histplot=True):
+def analyze_spectral(array, mask, histplot=None, label="default"):
     """This extracts the hyperspectral reflectance values of each pixel writes the values out to
        a file. It can also print out a histogram plot of pixel intensity
        and a pseudocolor image of the plant.
@@ -16,7 +17,8 @@ def analyze_spectral(array, mask, histplot=True):
     Inputs:
     array        = Hyperspectral data instance
     mask         = Binary mask made from selected contours
-    histplot     = if True plots histogram of reflectance intensity values
+    histplot     = (to be deprecated) if True plots histogram of reflectance intensity values
+    label        = optional label parameter, modifies the variable name of observations recorded
 
     Returns:
     analysis_img = output image
@@ -24,9 +26,12 @@ def analyze_spectral(array, mask, histplot=True):
     :param array: __main__.Spectral_data
     :param mask: numpy array
     :param histplot: bool
+    :param label: str
     :return analysis_img: ggplot
     """
-    params.device += 1
+    if histplot is not None:
+        deprecation_warning("'histplot' will be deprecated in a future version of PlantCV. "
+                            "Instead of a histogram this function plots the mean of spectra in the masked area.")
 
     array_data = array.array_data
 
@@ -53,10 +58,10 @@ def analyze_spectral(array, mask, histplot=True):
 
     for i, wavelength in enumerate(array.wavelength_dict):
         new_wavelengths.append(wavelength)
-        new_freq.append((wavelength_freq[i]).astype(np.float))
-        new_std_per_band.append(std_per_band[i].astype(np.float))
-        new_max_per_band.append(max_per_band[i].astype(np.float))
-        new_min_per_band.append(min_per_band[i].astype(np.float))
+        new_freq.append((wavelength_freq[i]).astype(float))
+        new_std_per_band.append(std_per_band[i].astype(float))
+        new_max_per_band.append(max_per_band[i].astype(float))
+        new_min_per_band.append(min_per_band[i].astype(float))
 
     # Calculate reflectance statistics
     avg_reflectance = np.average(wavelength_data)
@@ -68,47 +73,43 @@ def analyze_spectral(array, mask, histplot=True):
         wavelength_labels.append(i)
 
     # Store data into outputs class
-    outputs.add_observation(variable='global_mean_reflectance', trait='global mean reflectance',
+    outputs.add_observation(sample=label, variable='global_mean_reflectance', trait='global mean reflectance',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='reflectance',
                             datatype=float, value=float(avg_reflectance), label='reflectance')
-    outputs.add_observation(variable='global_median_reflectance', trait='global median reflectance',
+    outputs.add_observation(sample=label, variable='global_median_reflectance', trait='global median reflectance',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='reflectance',
                             datatype=float, value=float(median_reflectance), label='reflectance')
-    outputs.add_observation(variable='global_spectral_std', trait='pixel-wise standard deviation per band',
+    outputs.add_observation(sample=label, variable='global_spectral_std',
+                            trait='pixel-wise standard deviation per band',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='None', datatype=float,
                             value=float(std_reflectance), label='reflectance')
-    outputs.add_observation(variable='global_spectral_std', trait='pixel-wise standard deviation ',
+    outputs.add_observation(sample=label, variable='global_spectral_std', trait='pixel-wise standard deviation ',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='None', datatype=float,
                             value=float(std_reflectance), label='reflectance')
-    outputs.add_observation(variable='max_reflectance', trait='maximum reflectance per band',
+    outputs.add_observation(sample=label, variable='max_reflectance', trait='maximum reflectance per band',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='reflectance', datatype=list,
                             value=new_max_per_band, label=wavelength_labels)
-    outputs.add_observation(variable='min_reflectance', trait='minimum reflectance per band',
+    outputs.add_observation(sample=label, variable='min_reflectance', trait='minimum reflectance per band',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='reflectance', datatype=list,
                             value=new_min_per_band, label=wavelength_labels)
-    outputs.add_observation(variable='spectral_std', trait='pixel-wise standard deviation per band',
+    outputs.add_observation(sample=label, variable='spectral_std', trait='pixel-wise standard deviation per band',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='None', datatype=list,
                             value=new_std_per_band, label=wavelength_labels)
-    outputs.add_observation(variable='spectral_frequencies', trait='spectral frequencies',
+    outputs.add_observation(sample=label, variable='spectral_frequencies', trait='spectral frequencies',
                             method='plantcv.plantcv.hyperspectral.analyze_spectral', scale='frequency', datatype=list,
                             value=new_freq, label=wavelength_labels)
 
-    if histplot is True:
-        dataset = pd.DataFrame({'Wavelength (' + array.wavelength_units + ')': new_wavelengths,
-                                'Reflectance': wavelength_freq})
-        fig_hist = (ggplot(data=dataset,
-                           mapping=aes(x='Wavelength (' + array.wavelength_units + ')',
-                                       y='Reflectance'))
+    dataset = pd.DataFrame({'Wavelength (' + array.wavelength_units + ')': new_wavelengths,
+                            'Reflectance': wavelength_freq})
+    mean_spectra = (ggplot(data=dataset,
+                    mapping=aes(x='Wavelength (' + array.wavelength_units + ')', y='Reflectance'))
                     + geom_line(color='purple')
-                    + scale_x_continuous(
-                    breaks=list(range(int(np.floor(min_wavelength)), int(np.ceil(max_wavelength)), 50)))
+                    + scale_x_continuous(breaks=list(range(int(np.floor(min_wavelength)),
+                                                           int(np.ceil(max_wavelength)), 50)))
                     )
 
-        analysis_img = fig_hist
+    analysis_img = mean_spectra
 
-        if params.debug == "print":
-            fig_hist.save(os.path.join(params.debug_outdir, str(params.device) + '_spectral_histogram.png'))
-        elif params.debug == "plot":
-            print(fig_hist)
+    _debug(visual=mean_spectra, filename=os.path.join(params.debug_outdir, str(params.device) + "_mean_spectra.png"))
 
     return analysis_img
