@@ -1,13 +1,14 @@
 # Read in a hyperspectral data cube as an array and parse metadata from the header file
 
 import os
+import re
 import cv2
 import numpy as np
 from plantcv.plantcv import params
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import Spectral_data
 from plantcv.plantcv.transform import rescale
+from plantcv.plantcv import fatal_error
 
 
 def _find_closest(spectral_array, target):
@@ -45,7 +46,6 @@ def _make_pseudo_rgb(spectral_array):
     :param spectral_array: __main__.Spectral_data
     :return pseudo_rgb: numpy.ndarray
     """
-
     # Make shorter variable names for data from the spectral class instance object
     array_data = spectral_array.array_data
     default_bands = spectral_array.default_bands
@@ -91,6 +91,33 @@ def _make_pseudo_rgb(spectral_array):
     return pseudo_rgb
 
 
+def _find_hdr(filename):
+    """Find a header file paired with an hyperspectral data file.
+
+    Keyword arguments:
+    filename = File path/name of a hyperspectral data file.
+
+    Returns:
+    hdrfile = File path/name of hyperspectral header file.
+
+    :param filename: str
+    :return hdrfile: str
+    """
+    # Split the filename into the path and name
+    dat_path, dat_filename = os.path.split(filename)
+    # Extract the base of the data file name and the extension, if any
+    dat_basename, dat_ext = os.path.splitext(dat_filename)
+    # Create a regular expression for the header file
+    # The data file extension is included optionally
+    hdr_regex = re.compile(f"{dat_basename}({dat_ext})?.hdr")
+    # List all the files in the data file directory
+    for fname in os.listdir(dat_path):
+        # If the filename matches, return the header file path
+        if hdr_regex.match(fname):
+            return os.path.join(dat_path, fname)
+    return None
+
+
 def read_data(filename):
     """Read hyperspectral image data from file.
     Inputs:
@@ -101,14 +128,15 @@ def read_data(filename):
 
     :param filename: str
     :return spectral_array: __main__.Spectral_data
-        """
-
+    """
     # Initialize dictionary
     header_dict = {}
 
     # Remove any file extension and set .hdr filename
-    filename_base = os.path.splitext(filename)[0]
-    headername = filename_base + ".hdr"
+    headername = _find_hdr(filename=filename)
+
+    if headername is None:
+        fatal_error(f"Unable to find the header file corresponding to {filename}")
 
     with open(headername, "r") as f:
         # Replace characters for easier parsing
@@ -118,16 +146,22 @@ def read_data(filename):
         hdata = hdata.replace("{\n", "{")
         hdata = hdata.replace("\n}", "}")
         hdata = hdata.replace(" \n ", "")
+        hdata = hdata.replace(" \n", "")
         hdata = hdata.replace(";", "")
     hdata = hdata.split("\n")
 
     # Loop through and create a dictionary from the header file
-    for i, string in enumerate(hdata):
-        if ' = ' in string:
-            header_data = string.split(" = ")
+    # Try to reformat strings by replacing all " = " with '=' and " : "
+    for string in hdata:
+        # Remove white space for consistency across header file formats
+        string = string.replace(' ', '')
+        if '=' in string:
+            header_data = string.split("=")
+            header_data[0] = header_data[0].lower()
             header_dict.update({header_data[0].rstrip(): header_data[1].rstrip()})
-        elif ' : ' in string:
-            header_data = string.split(" : ")
+        elif ':' in string:
+            header_data = string.split(":")
+            header_data[0] = header_data[0].lower()
             header_dict.update({header_data[0].rstrip(): header_data[1].rstrip()})
 
     # Reformat wavelengths
@@ -143,29 +177,51 @@ def read_data(filename):
 
     # Replace datatype ID number with the numpy datatype
     dtype_dict = {"1": np.uint8, "2": np.int16, "3": np.int32, "4": np.float32, "5": np.float64, "6": np.complex64,
-                  "9": np.complex128, "12": np.uint16, "13": np.uint32, "14": np.uint64, "15": np.uint64}
-    header_dict["data type"] = dtype_dict[header_dict["data type"]]
+                  "9": np.complex128, "12": np.uint16, "13": np.uint32, "14": np.int64, "15": np.uint64}
+    header_dict["datatype"] = dtype_dict[header_dict["datatype"]]
 
     # Read in the data from the file
-    raw_data = np.fromfile(filename, header_dict["data type"], -1)
+    raw_data = np.fromfile(filename, header_dict["datatype"], -1)
 
     # Reshape the raw data into a datacube array
-    array_data = raw_data.reshape(int(header_dict["lines"]),
-                                  int(header_dict["bands"]),
-                                  int(header_dict["samples"])).transpose((0, 2, 1))
+    data_format = {
+        # Band Interleaved by Line (BIL)
+        "BIL": {
+            # Divide the raw data by Y (lines), Z (spectral bands), and X (samples)
+            # Then reorder into a cube in Y, X, Z order
+            "reshape": (int(header_dict["lines"]), int(header_dict["bands"]), int(header_dict["samples"])),
+            "transpose": (0, 2, 1)
+        },
+        # Band Sequential (BSQ)
+        "BSQ": {
+            # Divide the raw data by Z (spectral bands), Y (lines), and X (samples)
+            # Then reorder into a cube in Y, X, Z order
+            "reshape": (int(header_dict["bands"]), int(header_dict["lines"]), int(header_dict["samples"])),
+            "transpose": (1, 2, 0)
+        }
+    }
+    interleave_type = header_dict.get("interleave")
+    if interleave_type is not None:
+        interleave_type = interleave_type.upper()
+    if interleave_type not in data_format:
+        fatal_error(f"Interleave type {interleave_type} is not supported.")
+
+    # Reshape raw data into a data cube
+    array_data = raw_data.reshape(data_format[interleave_type]["reshape"]
+                                  ).transpose(data_format[interleave_type]["transpose"])
 
     # Check for default bands (that get used to make pseudo_rgb image)
     default_bands = None
-    if "default bands" in header_dict:
-        header_dict["default bands"] = header_dict["default bands"].replace("{", "")
-        header_dict["default bands"] = header_dict["default bands"].replace("}", "")
-        default_bands = header_dict["default bands"].split(",")
+    if "defaultbands" in header_dict:
+        header_dict["defaultbands"] = header_dict["defaultbands"].replace("{", "")
+        header_dict["defaultbands"] = header_dict["defaultbands"].replace("}", "")
+        default_bands = header_dict["defaultbands"].split(",")
 
     # Find array min and max values
     max_pixel = float(np.amax(array_data))
     min_pixel = float(np.amin(array_data))
 
-    wavelength_units = header_dict.get("wavelength units")
+    wavelength_units = header_dict.get("wavelengthunits")
     if wavelength_units is None:
         wavelength_units = "nm"
 
@@ -174,7 +230,7 @@ def read_data(filename):
                                    max_wavelength=float(str(header_dict["wavelength"][-1]).rstrip()),
                                    min_wavelength=float(str(header_dict["wavelength"][0]).rstrip()),
                                    max_value=max_pixel, min_value=min_pixel,
-                                   d_type=header_dict["data type"],
+                                   d_type=header_dict["datatype"],
                                    wavelength_dict=wavelength_dict, samples=int(header_dict["samples"]),
                                    lines=int(header_dict["lines"]), interleave=header_dict["interleave"],
                                    wavelength_units=wavelength_units, array_type="datacube",
@@ -184,9 +240,6 @@ def read_data(filename):
     pseudo_rgb = _make_pseudo_rgb(spectral_array)
     spectral_array.pseudo_rgb = pseudo_rgb
 
-    if params.debug == "plot":
-        plot_image(pseudo_rgb)
-    elif params.debug == "print":
-        print_image(pseudo_rgb, os.path.join(params.debug_outdir, str(params.device)+"_pseudo_rgb.png"))
+    _debug(visual=pseudo_rgb, filename=os.path.join(params.debug_outdir, str(params.device) + "_pseudo_rgb.png"))
 
     return spectral_array
