@@ -2,15 +2,15 @@
 
 import cv2
 import os
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import params
 
 
 def laplace_filter(gray_img, ksize, scale):
-    """This is a filtering method used to identify and highlight fine edges based on the 2nd derivative. A very
-       sensetive method to highlight edges but will also amplify background noise. ddepth = -1 specifies that the
-       dimensions of output image will be the same as the input image.
+    """Apply the Lapace filter.
+    This is a filtering method used to identify and highlight fine edges based on the 2nd derivative. A very
+    sensetive method to highlight edges but will also amplify background noise. ddepth = -1 specifies that the
+    dimensions of output image will be the same as the input image.
 
     Inputs:
     gray_img    = Grayscale image data
@@ -26,13 +26,11 @@ def laplace_filter(gray_img, ksize, scale):
     :param scale: int
     :return lp_filtered: numpy.ndarray
     """
-
     lp_filtered = cv2.Laplacian(src=gray_img, ddepth=-1, ksize=ksize, scale=scale)
-    params.device += 1
-    if params.debug == 'print':
-        print_image(lp_filtered,
-                    os.path.join(params.debug_outdir,
-                                 str(params.device) + '_lp_out_k' + str(ksize) + '_scale' + str(scale) + '.png'))
-    elif params.debug == 'plot':
-        plot_image(lp_filtered, cmap='gray')
+
+    _debug(visual=lp_filtered,
+           filename=os.path.join(params.debug_outdir,
+                                 str(params.device) + '_lp_out_k' + str(ksize) + '_scale' + str(scale) + '.png'),
+           cmap='gray')
+
     return lp_filtered
