@@ -7,24 +7,25 @@ from plantcv.plantcv import params
 from plantcv.plantcv import erode
 from plantcv.plantcv import dilate
 from plantcv.plantcv import outputs
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
 from plantcv.plantcv import find_objects
 from plantcv.plantcv import color_palette
+from plantcv.plantcv._debug import _debug
 
 
-def check_cycles(skel_img):
-    """ Check for cycles in a skeleton image
+def check_cycles(skel_img, label="default"):
+    """Check for cycles in a skeleton image.
+
     Inputs:
     skel_img     = Skeletonized image
+    label        = optional label parameter, modifies the variable name of observations recorded
 
     Returns:
     cycle_img    = Image with cycles identified
 
     :param skel_img: numpy.ndarray
+    :param label: str
     :return cycle_img: numpy.ndarray
     """
-
     # Create the mask needed for cv2.floodFill, must be larger than the image
     h, w = skel_img.shape[:2]
     mask = np.zeros((h + 2, w + 2), np.uint8)
@@ -56,23 +57,18 @@ def check_cycles(skel_img):
     if num_cycles > 0:
         # Get a new color scale
         rand_color = color_palette(num=num_cycles, saved=False)
-        for i, cnt in enumerate(cycle_objects):
+        for i in range(0, len(cycle_objects)):
             cv2.drawContours(cycle_img, cycle_objects, i, rand_color[i], params.line_thickness, lineType=8,
                              hierarchy=cycle_hierarchies)
 
     # Store Cycle Data
-    outputs.add_observation(variable='num_cycles', trait='number of cycles',
+    outputs.add_observation(sample=label, variable='num_cycles', trait='number of cycles',
                             method='plantcv.plantcv.morphology.check_cycles', scale='none', datatype=int,
                             value=int(num_cycles), label='none')
 
     # Reset debug mode
     params.debug = debug
-    # Auto-increment device
-    params.device += 1
 
-    if params.debug == 'print':
-        print_image(cycle_img, os.path.join(params.debug_outdir, str(params.device) + '_cycles.png'))
-    elif params.debug == 'plot':
-        plot_image(cycle_img)
+    _debug(visual=cycle_img, filename=os.path.join(params.debug_outdir, f"{params.device}_cycles.png"))
 
     return cycle_img
