@@ -6,27 +6,26 @@ import numpy as np
 import pandas as pd
 from plantcv.plantcv import params
 from plantcv.plantcv import outputs
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
 from plantcv.plantcv import color_palette
+from plantcv.plantcv._debug import _debug
 
 
-def segment_angle(segmented_img, objects):
-    """ Calculate angle of segments (in degrees) by fitting a linear regression line to segments.
+def segment_angle(segmented_img, objects, label="default"):
+    """Calculate angle of segments (in degrees) by fitting a linear regression line to segments.
 
-        Inputs:
-        segmented_img  = Segmented image to plot slope lines and angles on
-        objects        = List of contours
+    Inputs:
+    segmented_img  = Segmented image to plot slope lines and angles on
+    objects        = List of contours
+    label          = optional label parameter, modifies the variable name of observations recorded
 
-        Returns:
-        labeled_img    = Segmented debugging image with angles labeled
-
-
-        :param segmented_img: numpy.ndarray
-        :param objects: list
-        :return labeled_img: numpy.ndarray
-        """
+    Returns:
+    labeled_img    = Segmented debugging image with angles labeled
 
+    :param segmented_img: numpy.ndarray
+    :param objects: list
+    :param label: str
+    :return labeled_img: numpy.ndarray
+    """
     label_coord_x = []
     label_coord_y = []
     segment_angles = []
@@ -71,19 +70,12 @@ def segment_angle(segmented_img, objects):
         text = "{:.2f}".format(segment_angles[i])
         cv2.putText(img=labeled_img, text=text, org=(w, h), fontFace=cv2.FONT_HERSHEY_SIMPLEX,
                     fontScale=params.text_size, color=(150, 150, 150), thickness=params.text_thickness)
-        # segment_label = "ID" + str(i)
         segment_ids.append(i)
 
-    outputs.add_observation(variable='segment_angle', trait='segment angle',
+    outputs.add_observation(sample=label, variable='segment_angle', trait='segment angle',
                             method='plantcv.plantcv.morphology.segment_angle', scale='degrees', datatype=list,
                             value=segment_angles, label=segment_ids)
 
-    # Auto-increment device
-    params.device += 1
-
-    if params.debug == 'print':
-        print_image(labeled_img, os.path.join(params.debug_outdir, str(params.device) + '_segmented_angles.png'))
-    elif params.debug == 'plot':
-        plot_image(labeled_img)
+    _debug(visual=labeled_img, filename=os.path.join(params.debug_outdir, f"{params.device}_segmented_angles.png"))
 
     return labeled_img
