@@ -5,33 +5,32 @@ import cv2
 import numpy as np
 from plantcv.plantcv import dilate
 from plantcv.plantcv import params
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
 from plantcv.plantcv import logical_and
 from plantcv.plantcv.morphology import find_tips
+from plantcv.plantcv._debug import _debug
 
 
 def segment_sort(skel_img, objects, mask=None, first_stem=True):
-    """ Calculate segment curvature as defined by the ratio between geodesic and euclidean distance
+    """Sort segments from a skeletonized image into two categories: leaf objects and other objects.
 
-        Inputs:
-        skel_img          = Skeletonized image
-        objects           = List of contours
-        mask              = (Optional) binary mask for debugging. If provided, debug image will be overlaid on the mask.
-        first_stem        = (Optional) if True, then the first (bottom) segment always gets classified as stem
+    Inputs:
+    skel_img          = Skeletonized image
+    objects           = List of contours
+    mask              = (Optional) binary mask for debugging. If provided, debug image will be overlaid on the mask.
+    first_stem        = (Optional) if True, then the first (bottom) segment always gets classified as stem
 
-        Returns:
-        labeled_img       = Segmented debugging image with lengths labeled
-        secondary_objects = List of secondary segments (leaf)
-        primary_objects   = List of primary objects (stem)
+    Returns:
+    labeled_img       = Segmented debugging image with lengths labeled
+    secondary_objects = List of secondary segments (leaf)
+    primary_objects   = List of primary objects (stem)
 
-        :param skel_img: numpy.ndarray
-        :param objects: list
-        :param mask: numpy.ndarray
-        :param first_stem: bool
-        :return secondary_objects: list
-        :return other_objects: list
-        """
+    :param skel_img: numpy.ndarray
+    :param objects: list
+    :param mask: numpy.ndarray
+    :param first_stem: bool
+    :return secondary_objects: list
+    :return other_objects: list
+    """
     # Store debug
     debug = params.debug
     params.debug = None
@@ -51,7 +50,6 @@ def segment_sort(skel_img, objects, mask=None, first_stem=True):
     for i, cnt in enumerate(objects):
         segment_plot = np.zeros(skel_img.shape[:2], np.uint8)
         cv2.drawContours(segment_plot, objects, i, 255, 1, lineType=8)
-        # is_leaf = False
         overlap_img = logical_and(segment_plot, tips_img)
 
         # The first contour is the base, and while it contains a tip, it isn't a leaf
@@ -63,7 +61,6 @@ def segment_sort(skel_img, objects, mask=None, first_stem=True):
 
             if np.sum(overlap_img) > 0:
                 secondary_objects.append(cnt)
-                # is_leaf = True
             else:
                 primary_objects.append(cnt)
 
@@ -77,12 +74,6 @@ def segment_sort(skel_img, objects, mask=None, first_stem=True):
     for i, cnt in enumerate(secondary_objects):
         cv2.drawContours(labeled_img, secondary_objects, i, (0, 255, 0), params.line_thickness, lineType=8)
 
-    # Auto-increment device
-    params.device += 1
-
-    if params.debug == 'print':
-        print_image(labeled_img, os.path.join(params.debug_outdir, str(params.device) + '_sorted_segments.png'))
-    elif params.debug == 'plot':
-        plot_image(labeled_img)
+    _debug(visual=labeled_img, filename=os.path.join(params.debug_outdir, f"{params.device}_sorted_segments.png"))
 
     return secondary_objects, primary_objects
