@@ -4,21 +4,21 @@ import cv2
 import numpy as np
 import os
 from plantcv.plantcv import fatal_error
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
 from plantcv.plantcv import rgb2gray_hsv
 from plantcv.plantcv import find_objects
 from plantcv.plantcv.threshold import binary as binary_threshold
 from plantcv.plantcv import roi_objects
 from plantcv.plantcv import object_composition
 from plantcv.plantcv import apply_mask
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import params
 from plantcv.plantcv import outputs
 
 
 def report_size_marker_area(img, roi_contour, roi_hierarchy, marker='define', objcolor='dark', thresh_channel=None,
-                            thresh=None):
-    """Detects a size marker in a specified region and reports its size and eccentricity
+                            thresh=None, label="default"):
+    """
+    Detects a size marker in a specified region and reports its size and eccentricity
 
     Inputs:
     img             = An RGB or grayscale image to plot the marker object on
@@ -29,6 +29,7 @@ def report_size_marker_area(img, roi_contour, roi_hierarchy, marker='define', ob
     objcolor        = Object color is 'dark' or 'light' (is the marker darker or lighter than the background)
     thresh_channel  = 'h', 's', or 'v' for hue, saturation or value
     thresh          = Binary threshold value (integer)
+    label      = optional label parameter, modifies the variable name of observations recorded
 
     Returns:
     analysis_images = List of output images
@@ -40,6 +41,7 @@ def report_size_marker_area(img, roi_contour, roi_hierarchy, marker='define', ob
     :param objcolor: str
     :param thresh_channel: str
     :param thresh: int
+    :param label: str
     :return: analysis_images: list
     """
     # Store debug
@@ -119,21 +121,21 @@ def report_size_marker_area(img, roi_contour, roi_hierarchy, marker='define', ob
     # Reset debug mode
     params.debug = debug
 
-    if params.debug == 'print':
-        print_image(ref_img, os.path.join(params.debug_outdir, str(params.device) + '_marker_shape.png'))
-    elif params.debug == 'plot':
-        plot_image(ref_img)
+    _debug(visual=ref_img,
+           filename=os.path.join(params.debug_outdir, str(params.device) + '_marker_shape.png'))
 
-    outputs.add_observation(variable='marker_area', trait='marker area',
+    outputs.add_observation(sample=label, variable='marker_area', trait='marker area',
                             method='plantcv.plantcv.report_size_marker_area', scale='pixels', datatype=int,
                             value=marker_area, label='pixels')
-    outputs.add_observation(variable='marker_ellipse_major_axis', trait='marker ellipse major axis length',
+    outputs.add_observation(sample=label, variable='marker_ellipse_major_axis',
+                            trait='marker ellipse major axis length',
                             method='plantcv.plantcv.report_size_marker_area', scale='pixels', datatype=int,
                             value=major_axis_length, label='pixels')
-    outputs.add_observation(variable='marker_ellipse_minor_axis', trait='marker ellipse minor axis length',
+    outputs.add_observation(sample=label, variable='marker_ellipse_minor_axis',
+                            trait='marker ellipse minor axis length',
                             method='plantcv.plantcv.report_size_marker_area', scale='pixels', datatype=int,
                             value=minor_axis_length, label='pixels')
-    outputs.add_observation(variable='marker_ellipse_eccentricity', trait='marker ellipse eccentricity',
+    outputs.add_observation(sample=label, variable='marker_ellipse_eccentricity', trait='marker ellipse eccentricity',
                             method='plantcv.plantcv.report_size_marker_area', scale='none', datatype=float,
                             value=eccentricity, label='none')
 
