@@ -3,20 +3,21 @@
 import cv2
 import os
 import numpy as np
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import params
 from plantcv.plantcv import outputs
 from plantcv.plantcv import fatal_error
 
 
-def x_axis_pseudolandmarks(img, obj, mask):
-    """Divide up object contour into 20 equidistance segments and generate landmarks for each
+def x_axis_pseudolandmarks(img, obj, mask, label="default"):
+    """
+    Divide up object contour into 20 equidistance segments and generate landmarks for each
 
     Inputs:
     img      = This is a copy of the original plant image generated using np.copy if debug is true it will be drawn on
     obj      = a contour of the plant object (this should be output from the object_composition.py fxn)
     mask     = this is a binary image. The object should be white and the background should be black
+    label    = optional label parameter, modifies the variable name of observations recorded
 
     Returns:
     top      = List of landmark points within 'top' portion
@@ -26,13 +27,12 @@ def x_axis_pseudolandmarks(img, obj, mask):
     :param img: numpy.ndarray
     :param obj: list
     :param mask: numpy.ndarray
+    :param label: str
     :return top: list
     :return bottom: list
     :return center_v: list
     """
-
     # Lets get some landmarks scanning along the x-axis
-    params.device += 1
     if not np.any(obj):
         return ('NA', 'NA'), ('NA', 'NA'), ('NA', 'NA')
     x, y, width, height = cv2.boundingRect(obj)
@@ -162,11 +162,10 @@ def x_axis_pseudolandmarks(img, obj, mask):
             x = i[0, 0]
             y = i[0, 1]
             cv2.circle(img2, (int(x), int(y)), params.line_thickness, (0, 79, 255), -1)
-        if params.debug == 'plot':
-            plot_image(img2)
-        elif params.debug == 'print':
-            print_image(img2,
-                        os.path.join(params.debug_outdir, (str(params.device) + '_x_axis_pseudolandmarks.png')))
+
+        _debug(visual=img2,
+               filename=os.path.join(params.debug_outdir, (str(params.device) + '_x_axis_pseudolandmarks.png')))
+
     elif extent < 21:
         # If the width of the object is less than 20 pixels just make the object a 20 pixel rectangle
         x, y, width, height = cv2.boundingRect(obj)
@@ -203,10 +202,9 @@ def x_axis_pseudolandmarks(img, obj, mask):
             x = i[0, 0]
             y = i[0, 1]
             cv2.circle(img2, (int(x), int(y)), params.line_thickness, (0, 79, 255), -1)
-        if params.debug == 'plot':
-            plot_image(img2)
-        elif params.debug == 'print':
-            print_image(img2, os.path.join(params.debug_outdir, (str(params.device) + '_x_axis_pseudolandmarks.png')))
+
+        _debug(visual=img2,
+               filename=os.path.join(params.debug_outdir, (str(params.device) + '_x_axis_pseudolandmarks.png')))
 
     # Store into global measurements
     for pt in top:
@@ -216,13 +214,13 @@ def x_axis_pseudolandmarks(img, obj, mask):
     for pt in center_v:
         center_v_list.append(pt[0].tolist())
 
-    outputs.add_observation(variable='top_lmk', trait='top landmark coordinates',
+    outputs.add_observation(sample=label, variable='top_lmk', trait='top landmark coordinates',
                             method='plantcv.plantcv.x_axis_pseudolandmarks', scale='none', datatype=tuple,
                             value=tuple(top_list), label='none')
-    outputs.add_observation(variable='bottom_lmk', trait='bottom landmark coordinates',
+    outputs.add_observation(sample=label, variable='bottom_lmk', trait='bottom landmark coordinates',
                             method='plantcv.plantcv.x_axis_pseudolandmarks', scale='none', datatype=tuple,
                             value=tuple(bottom_list), label='none')
-    outputs.add_observation(variable='center_v_lmk', trait='center vertical landmark coordinates',
+    outputs.add_observation(sample=label, variable='center_v_lmk', trait='center vertical landmark coordinates',
                             method='plantcv.plantcv.x_axis_pseudolandmarks', scale='none', datatype=tuple,
                             value=tuple(center_v_list), label='none')
 
